@@ -145,6 +145,11 @@ public:
 		return defaultHandler(context, expr, {});
 	}
 
+	virtual VisitResult visit(PercentualExpression* expr) override
+	{
+		return _handleUnaryOperation(expr);
+	}
+
 	virtual VisitResult visit(NotExpression* expr) override
 	{
 		return _handleUnaryOperation(expr);
@@ -302,7 +307,13 @@ public:
 		TokenStreamContext context{expr};
 		auto var = expr->getVariable()->accept(this);
 		auto iterable = expr->getIterable()->accept(this);
-		return defaultHandler(context, expr, var, iterable, {});
+		if (expr->getRangeExpression())
+		{
+			auto rangeExpr = expr->getRangeExpression()->accept(this);
+			return defaultHandler(context, expr, var, iterable, {}, rangeExpr);
+		}
+		else
+			return defaultHandler(context, expr, var, iterable, {});
 	}
 
 	virtual VisitResult visit(IterableExpression* expr) override
@@ -334,6 +345,7 @@ public:
 	}
 
 	virtual VisitResult visit(IdExpression*) override { return {}; }
+	virtual VisitResult visit(IdWildcardExpression*) override { return {}; }
 
 	virtual VisitResult visit(StructAccessExpression* expr) override
 	{
@@ -372,6 +384,7 @@ public:
 	virtual VisitResult visit(EntrypointExpression*) override { return {}; }
 	virtual VisitResult visit(AllExpression*) override { return {}; }
 	virtual VisitResult visit(AnyExpression*) override { return {}; }
+	virtual VisitResult visit(NoneExpression*) override { return {}; }
 	virtual VisitResult visit(ThemExpression*) override { return {}; }
 
 	virtual VisitResult visit(ParenthesesExpression* expr) override
@@ -538,6 +551,40 @@ public:
 		return {};
 	}
 
+	VisitResult defaultHandler(const TokenStreamContext& context, OfExpression* expr, const VisitResult& varRet, const VisitResult& iterableRet, const VisitResult& bodyRet, const VisitResult& rangeRet)
+	{
+		(void) bodyRet;
+		if (auto var = std::get_if<Expression::Ptr>(&varRet))
+		{
+			if (*var)
+				expr->setVariable(*var);
+		}
+		else
+			expr->setVariable(nullptr);
+
+		if (auto iterable = std::get_if<Expression::Ptr>(&iterableRet))
+		{
+			if (*iterable)
+				expr->setIterable(*iterable);
+		}
+		else
+			expr->setIterable(nullptr);
+
+		if (auto rangeExpr = std::get_if<Expression::Ptr>(&rangeRet))
+		{
+			if (*rangeExpr)
+				expr->setRangeExpression(*rangeExpr);
+		}
+		else
+			expr->setRangeExpression(nullptr);
+
+		// If any subnode needs to be deleted, we delete whole expr.
+		if (!expr->getVariable() || !expr->getIterable() || !expr->getRangeExpression())
+			return VisitAction::Delete;
+
+		return {};
+	}
+
 	VisitResult defaultHandler(const TokenStreamContext& context, IterableExpression* expr, const std::vector<VisitResult>& elementsRet)
 	{
 		if (elementsRet.empty())
