@@ -28,6 +28,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_StringLengthExpression", py::overload_cast<StringLengthExpression*>(&Visitor::visit))
 		.def("visit_NotExpression", py::overload_cast<NotExpression*>(&Visitor::visit))
 		.def("visit_DefinedExpression", py::overload_cast<DefinedExpression*>(&Visitor::visit))
+		.def("visit_PercentualExpression", py::overload_cast<PercentualExpression*>(&Visitor::visit))
 		.def("visit_UnaryMinusExpression", py::overload_cast<UnaryMinusExpression*>(&Visitor::visit))
 		.def("visit_BitwiseNotExpression", py::overload_cast<BitwiseNotExpression*>(&Visitor::visit))
 		.def("visit_AndExpression", py::overload_cast<AndExpression*>(&Visitor::visit))
@@ -59,6 +60,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_SetExpression", py::overload_cast<SetExpression*>(&Visitor::visit))
 		.def("visit_RangeExpression", py::overload_cast<RangeExpression*>(&Visitor::visit))
 		.def("visit_IdExpression", py::overload_cast<IdExpression*>(&Visitor::visit))
+		.def("visit_IdWildcardExpression", py::overload_cast<IdWildcardExpression*>(&Visitor::visit))
 		.def("visit_StructAccessExpression", py::overload_cast<StructAccessExpression*>(&Visitor::visit))
 		.def("visit_ArrayAccessExpression", py::overload_cast<ArrayAccessExpression*>(&Visitor::visit))
 		.def("visit_FunctionCallExpression", py::overload_cast<FunctionCallExpression*>(&Visitor::visit))
@@ -70,6 +72,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_EntrypointExpression", py::overload_cast<EntrypointExpression*>(&Visitor::visit))
 		.def("visit_AllExpression", py::overload_cast<AllExpression*>(&Visitor::visit))
 		.def("visit_AnyExpression", py::overload_cast<AnyExpression*>(&Visitor::visit))
+		.def("visit_NoneExpression", py::overload_cast<NoneExpression*>(&Visitor::visit))
 		.def("visit_ThemExpression", py::overload_cast<ThemExpression*>(&Visitor::visit))
 		.def("visit_ParenthesesExpression", py::overload_cast<ParenthesesExpression*>(&Visitor::visit))
 		.def("visit_IntFunctionExpression", py::overload_cast<IntFunctionExpression*>(&Visitor::visit))
@@ -87,6 +90,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_StringLengthExpression", py::overload_cast<StringLengthExpression*>(&ObservingVisitor::visit))
 		.def("visit_NotExpression", py::overload_cast<NotExpression*>(&ObservingVisitor::visit))
 		.def("visit_DefinedExpression", py::overload_cast<DefinedExpression*>(&ObservingVisitor::visit))
+		.def("visit_PercentualExpression", py::overload_cast<PercentualExpression*>(&ObservingVisitor::visit))
 		.def("visit_UnaryMinusExpression", py::overload_cast<UnaryMinusExpression*>(&ObservingVisitor::visit))
 		.def("visit_BitwiseNotExpression", py::overload_cast<BitwiseNotExpression*>(&ObservingVisitor::visit))
 		.def("visit_AndExpression", py::overload_cast<AndExpression*>(&ObservingVisitor::visit))
@@ -118,6 +122,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_SetExpression", py::overload_cast<SetExpression*>(&ObservingVisitor::visit))
 		.def("visit_RangeExpression", py::overload_cast<RangeExpression*>(&ObservingVisitor::visit))
 		.def("visit_IdExpression", py::overload_cast<IdExpression*>(&ObservingVisitor::visit))
+		.def("visit_IdWildcardExpression", py::overload_cast<IdWildcardExpression*>(&ObservingVisitor::visit))
 		.def("visit_StructAccessExpression", py::overload_cast<StructAccessExpression*>(&ObservingVisitor::visit))
 		.def("visit_ArrayAccessExpression", py::overload_cast<ArrayAccessExpression*>(&ObservingVisitor::visit))
 		.def("visit_FunctionCallExpression", py::overload_cast<FunctionCallExpression*>(&ObservingVisitor::visit))
@@ -129,6 +134,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_EntrypointExpression", py::overload_cast<EntrypointExpression*>(&ObservingVisitor::visit))
 		.def("visit_AllExpression", py::overload_cast<AllExpression*>(&ObservingVisitor::visit))
 		.def("visit_AnyExpression", py::overload_cast<AnyExpression*>(&ObservingVisitor::visit))
+		.def("visit_NoneExpression", py::overload_cast<NoneExpression*>(&ObservingVisitor::visit))
 		.def("visit_ThemExpression", py::overload_cast<ThemExpression*>(&ObservingVisitor::visit))
 		.def("visit_ParenthesesExpression", py::overload_cast<ParenthesesExpression*>(&ObservingVisitor::visit))
 		.def("visit_IntFunctionExpression", py::overload_cast<IntFunctionExpression*>(&ObservingVisitor::visit))
@@ -147,6 +153,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_StringLengthExpression", py::overload_cast<StringLengthExpression*>(&ModifyingVisitor::visit))
 		.def("visit_NotExpression", py::overload_cast<NotExpression*>(&ModifyingVisitor::visit))
 		.def("visit_DefinedExpression", py::overload_cast<DefinedExpression*>(&ModifyingVisitor::visit))
+		.def("visit_PercentualExpression", py::overload_cast<PercentualExpression*>(&ModifyingVisitor::visit))
 		.def("visit_UnaryMinusExpression", py::overload_cast<UnaryMinusExpression*>(&ModifyingVisitor::visit))
 		.def("visit_BitwiseNotExpression", py::overload_cast<BitwiseNotExpression*>(&ModifyingVisitor::visit))
 		.def("visit_AndExpression", py::overload_cast<AndExpression*>(&ModifyingVisitor::visit))
@@ -178,6 +185,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_SetExpression", py::overload_cast<SetExpression*>(&ModifyingVisitor::visit))
 		.def("visit_RangeExpression", py::overload_cast<RangeExpression*>(&ModifyingVisitor::visit))
 		.def("visit_IdExpression", py::overload_cast<IdExpression*>(&ModifyingVisitor::visit))
+		.def("visit_IdWildcardExpression", py::overload_cast<IdWildcardExpression*>(&ModifyingVisitor::visit))
 		.def("visit_StructAccessExpression", py::overload_cast<StructAccessExpression*>(&ModifyingVisitor::visit))
 		.def("visit_ArrayAccessExpression", py::overload_cast<ArrayAccessExpression*>(&ModifyingVisitor::visit))
 		.def("visit_FunctionCallExpression", py::overload_cast<FunctionCallExpression*>(&ModifyingVisitor::visit))
@@ -189,6 +197,7 @@ void addVisitorClasses(py::module& module)
 		.def("visit_EntrypointExpression", py::overload_cast<EntrypointExpression*>(&ModifyingVisitor::visit))
 		.def("visit_AllExpression", py::overload_cast<AllExpression*>(&ModifyingVisitor::visit))
 		.def("visit_AnyExpression", py::overload_cast<AnyExpression*>(&ModifyingVisitor::visit))
+		.def("visit_NoneExpression", py::overload_cast<NoneExpression*>(&ModifyingVisitor::visit))
 		.def("visit_ThemExpression", py::overload_cast<ThemExpression*>(&ModifyingVisitor::visit))
 		.def("visit_ParenthesesExpression", py::overload_cast<ParenthesesExpression*>(&ModifyingVisitor::visit))
 		.def("visit_IntFunctionExpression", py::overload_cast<IntFunctionExpression*>(&ModifyingVisitor::visit))
@@ -199,6 +208,7 @@ void addVisitorClasses(py::module& module)
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, StringLengthExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, NotExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, DefinedExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
+		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, PercentualExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, UnaryMinusExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, BitwiseNotExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, AndExpression*, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
