@@ -16,6 +16,18 @@ namespace yaramod {
 
 constexpr unsigned tabulator_length = 8;
 
+
+std::pair<TokenIt, TokenIt> TokenStream::findBounds(TokenIt embedded, TokenType leftType, TokenType rightType) const
+{
+	auto left = embedded;
+	auto right = embedded;
+	while (left != begin() && left->getType() != leftType)
+		left = std::prev(left);
+	while (right != end() && right->getType() != rightType)
+		right = std::next(right);
+	return std::make_pair(left, right);
+}
+
 TokenIt TokenStream::emplace_back(TokenType type, char value)
 {
 	_tokens.emplace_back(type, Literal(std::string(1, value)));
@@ -335,12 +347,18 @@ std::vector<std::string> TokenStream::getTokensAsText() const
 {
 	std::vector<std::string> output;
 	for (auto t : _tokens)
-	{
 		output.push_back(t.getPureText());
-	}
 	return output;
 }
 
+std::string TokenStream::getTokensAsString() const
+{
+	std::stringstream ss;
+	for (const auto& t : getTokensAsText())
+		ss << "'" << t << "', ";
+    return ss.str();
+}
+
 void TokenStream::clear()
 {
 	_tokens.clear();
@@ -490,6 +508,62 @@ void TokenStream::removeRedundantDoubleNewlines()
 	}
 }
 
+void TokenStream::comment(const std::string& message, bool multiline, const std::string& indent, bool linebreak)
+{
+	auto insert_before = empty() ? end() : begin();
+	commentBeforeToken(message, insert_before, multiline, indent, linebreak);
+}
+
+void TokenStream::commentBehind(const std::string& message, bool multiline, const std::string& indent, bool linebreak)
+{
+	auto insert_before = end();
+	while (insert_before != begin())
+	{
+		auto predecessor = std::prev(insert_before);
+		if (predecessor->getType() == TokenType::NEW_LINE)
+			--insert_before;
+		else
+			break;
+	}
+	commentBeforeToken(message, insert_before, multiline, indent, linebreak);
+}
+
+void TokenStream::commentBeforeToken(const std::string& message, TokenIt insert_before, bool multiline, const std::string& indent, bool linebreak)
+{
+	if (!message.empty())
+	{
+		std::stringstream ss;
+		ss << indent;
+		if (multiline)
+		{
+			ss << "/*";
+			if (message.front() != '\n')
+				ss << " ";
+			for (auto c : message)
+			{
+				ss << c;
+				if (c == '\n')
+					ss << indent;
+			}
+			if (message.back() != '\n')
+				ss << " ";
+			ss << "*/";
+			emplace(insert_before, TokenType::COMMENT, ss.str());
+		}
+		else
+		{
+			for (auto item : message)
+				if (item == '\n')
+					throw YaramodError("Error: one-line comment must not contain \\n.");
+			ss << "// " << message;
+			emplace(insert_before, TokenType::ONELINE_COMMENT, ss.str());
+		}
+		// if (insert_before != end() && (linebreak || !multiline))
+		if (linebreak)
+			emplace(insert_before, TokenType::NEW_LINE, "\n");
+	}
+}
+
 void TokenStream::addMissingNewLines()
 {
 	BracketStack brackets;
@@ -884,6 +958,7 @@ void TokenStream::getTextProcedure(PrintHelper& helper, std::stringstream* os, b
 						helper.insertIntoStream(os, ' ');
 					break;
 				default:
+					auto nextNextIt = std::next(nextIt);
 					switch(next)
 					{
 						case TokenType::RP:
@@ -901,14 +976,21 @@ void TokenStream::getTextProcedure(PrintHelper& helper, std::stringstream* os, b
 							[[fallthrough]];
 						default:
 							if (next != TokenType::LSQB || (current != TokenType::STRING_OFFSET && current != TokenType::STRING_LENGTH))
-								helper.insertIntoStream(os, ' ');
+							{
+								if (next != TokenType::PERCENT || nextNextIt == end() || nextNextIt->getType() != TokenType::OF)
+									helper.insertIntoStream(os, ' ');
+							}
 					}
 			}
 		}
 		else if (inside_enumeration_brackets)
 		{
 			if ((current != TokenType::LP_ENUMERATION && next != TokenType::RP_ENUMERATION) && (current != TokenType::LSQB_ENUMERATION && next != TokenType::RSQB_ENUMERATION) && current != TokenType::DOT && next != TokenType::COMMA && next != TokenType::DOT && next != TokenType::NEW_LINE)
-				helper.insertIntoStream(os, ' ');
+			{
+				// we ran into <rule_id>* and we don't want space in between them
+				if (!(current == TokenType::ID_WILDCARD && next == TokenType::ID_WILDCARD))
+					helper.insertIntoStream(os, ' ');
+			}
 		}
 		else if (current == TokenType::HEX_ALT_RIGHT_BRACKET || current == TokenType::HEX_ALT_LEFT_BRACKET)
 			helper.insertIntoStream(os, ' ');
